@@ -8,13 +8,6 @@
 #include "win32.h"
 #endif
 
-#ifndef LC_LINEBUF_LEN
-#define LC_LINEBUF_LEN 1024
-#endif
-
-#ifndef HAVE_STRTOLL
-#include "strtoll.h"
-#endif
 #ifndef HAVE_STRSEP
 #include "strsep.h"
 #endif
